summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--server/src/main.rs2
1 files changed, 1 insertions, 1 deletions
diff --git a/server/src/main.rs b/server/src/main.rs
index 052cee2..a099a13 100644
--- a/server/src/main.rs
+++ b/server/src/main.rs
@@ -147,7 +147,7 @@ async fn db_create_login_token(db: DB, username: &str) -> Result<String, ()> {
match sqlx::query("insert into Logins (user, token, expire) values ($1, $2, $3)")
.bind(username)
.bind(&token)
- .bind(now as i64 + 8 * 24 * 3600) // valid for 8 days
+ .bind(now as i64 + 40 * 24 * 3600) // valid for 40 days
.execute(conn.deref_mut()).await {
Ok(_) => Ok(token),
Err(_) => Err(()),